@@ -1,5 +1,5 @@
 import sys
-from typing import Generic, TypeVar
+from typing import Any, TypeVar
 
 from pychoir.core import Matcher
 
@@ -8,15 +8,17 @@ T = TypeVar('T', contravariant=True)
 if sys.version_info >= (3, 8):
     from typing import Protocol
 
-    class MatcherLike(Protocol[T]):
+    class _MatcherLike(Protocol[T]):
         def matches(self, other: T) -> bool:
             ...  # pragma: no cover
+
+    MatcherLike = _MatcherLike[T]
 else:
-    MatcherLike = Generic
+    MatcherLike = Any
 
 
 class Matches(Matcher):
-    def __init__(self, *matchers: MatcherLike[T]):
+    def __init__(self, *matchers: MatcherLike):
         super().__init__()
         self.matchers = matchers
 
